@@ -4,13 +4,10 @@ use Moo;
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
-our $VERSION = '0.000018';
+our $VERSION = '0.000019';
 
 use Class::Inspector ();
-use Class::Unload    ();
-use Data::Dumper qw( Dumper );
 use List::Util qw( any );
-use Log::Dispatch::Array ();
 use Module::Runtime qw( require_module );
 use Sub::HandlesVia;
 use Try::Tiny qw( catch try );
@@ -62,6 +59,13 @@ has class_isa => (
     default => sub { shift->_implicit->{class_isa} },
 );
 
+has has_fatal_error => (
+    is      => 'ro',
+    isa     => Bool,
+    lazy    => 1,
+    default => sub { shift->_implicit->{fatal_error} ? 1 : 0 },
+);
+
 has _implicit => (
     is      => 'ro',
     isa     => HashRef,
@@ -173,13 +177,6 @@ has pkg_isa => (
     },
 );
 
-has uses_import_into => (
-    is      => 'ro',
-    isa     => Bool,
-    lazy    => 1,
-    builder => '_build_uses_import_into',
-);
-
 has uses_moose => (
     is      => 'ro',
     isa     => Bool,
@@ -202,10 +199,8 @@ sub _build_explicit_exports {
     # If this is Sub::Exporter, we can cheat and see what's in the :all tag
     my $pkg           = $self->_pkg_for('all');
     my $use_statement = sprintf( 'use %s qw(:all);', $self->_module_name );
-    return $self->_list_to_hash(
-        $pkg,
-        $self->_exports_for_include( $pkg, $use_statement )
-    );
+    my ($exports)     = $self->_exports_for_include( $pkg, $use_statement );
+    return $self->_list_to_hash( $pkg, $exports );
 
     # If this module uses something other than Exporter or Sub::Exporter, we
     # probably returned an empty hash above.  We could guess and say it's the
@@ -301,7 +296,8 @@ sub _build_implicit {
     my $module_name   = $self->_module_name;
     my $pkg           = $self->_pkg_for('implicit');
     my $use_statement = "use $module_name;";
-    my $maybe_exports = $self->_exports_for_include( $pkg, $use_statement );
+    my ( $maybe_exports, $fatal_error )
+        = $self->_exports_for_include( $pkg, $use_statement );
 
     no strict 'refs';
     my $aggregated = {
@@ -310,45 +306,13 @@ sub _build_implicit {
         export_fail    => [ @{ $self->_module_name . '::EXPORT_FAIL' } ],
         export_ok      => [ @{ $self->_module_name . '::EXPORT_OK' } ],
         export_tags    => [ @{ $self->_module_name . '::EXPORT_TAGS' } ],
+        fatal_error    => $fatal_error,
         _maybe_exports => $maybe_exports,
     };
 
     return $aggregated;
 }
 
-sub _build_uses_import_into {
-    my $self           = shift;
-    my $already_loaded = Class::Inspector->loaded('Import::Into');
-    if ($already_loaded) {
-
-        #Class::Unload->unload ($self->_module_name );
-        Class::Unload->unload('Import::Into');
-        delete $import::{into};
-        delete $unimport::{out_of};
-    }
-    my $pkg           = $self->_pkg_for('uses::import::into');
-    my $use_statement = sprintf( 'use %s;', $self->_module_name );
-
-    my @log;
-    $self->logger->add(
-        Log::Dispatch::Array->new(
-            name      => 'import_into_logger',
-            min_level => 'warning',
-            array     => \@log,
-        )
-    );
-    $self->_exports_for_include( $pkg, $use_statement );
-
-    my $uses_import_into = Class::Inspector->loaded('Import::Into')
-        || any { $_->{message} =~ q{"into" via package "import"} } @log;
-
-    if ( $already_loaded && !$uses_import_into ) {
-        require_module('Import::Into');
-        Import::Into->import;
-    }
-    return $uses_import_into;
-}
-
 sub _exports_for_include {
     my $self          = shift;
     my $pkg           = shift;
@@ -405,6 +369,7 @@ EOF
 
     if ($@) {
         $logger_cb->($@);
+        return undef, $@;
     }
 
     ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -415,7 +380,7 @@ EOF
     use strict;
     ## use critic
 
-    return \@export;
+    return \@export, undef;
 }
 
 sub _pkg_for {
@@ -513,7 +478,7 @@ App::perlimports::ExportInspector - Inspect code for exportable symbols
 
 =head1 VERSION
 
-version 0.000018
+version 0.000019
 
 =head1 SYNOPSIS
 
